==> igniteui-react-core-16.15.1.tgz: package/esm2015/lib/WebRangeSliderValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescriptionMetadata } from "./WebRangeSliderValueDescriptionMetadata";
import { WebRangeSliderValueEventArgsDescription } from "./WebRangeSliderValueEventArgsDescription";
/**
 * @hidden
 */
export let WebRangeSliderValueEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRangeSliderValueEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRangeSliderValueEventArgsDescriptionMetadata.a == null) {
                WebRangeSliderValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRangeSliderValueEventArgsDescriptionMetadata.c(WebRangeSliderValueEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebRangeSliderValueEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebRangeSliderValueEventArgsDescriptionMetadata.a);
            WebRangeSliderValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RangeSliderValueEventArgs");
            a.item("Detail", "ExportedType:RangeSliderValue");
        }
        static d(a) {
            WebRangeSliderValueEventArgsDescriptionMetadata.b(a);
            a.u("WebRangeSliderValueEventArgs", () => new WebRangeSliderValueEventArgsDescription());
            a.t("WebRangeSliderValueEventArgs", WebRangeSliderValueEventArgsDescriptionMetadata.a);
        }
    }
    WebRangeSliderValueEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRangeSliderValueEventArgsDescriptionMetadata, 'WebRangeSliderValueEventArgsDescriptionMetadata');
    WebRangeSliderValueEventArgsDescriptionMetadata.a = null;
    return WebRangeSliderValueEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-16.16.1.tgz: package/esm2015/lib/WebRangeSliderValueEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescriptionMetadata } from "./WebRangeSliderValueDescriptionMetadata";
import { WebRangeSliderValueEventArgsDescription } from "./WebRangeSliderValueEventArgsDescription";
/**
 * @hidden
 */
export let WebRangeSliderValueEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRangeSliderValueEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRangeSliderValueEventArgsDescriptionMetadata.a == null) {
                WebRangeSliderValueEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRangeSliderValueEventArgsDescriptionMetadata.c(WebRangeSliderValueEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebRangeSliderValueEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebRangeSliderValueEventArgsDescriptionMetadata.a);
            WebRangeSliderValueDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RangeSliderValueEventArgs");
            a.item("Detail", "ExportedType:WebRangeSliderValue");
        }
        static d(a) {
            WebRangeSliderValueEventArgsDescriptionMetadata.b(a);
            a.u("WebRangeSliderValueEventArgs", () => new WebRangeSliderValueEventArgsDescription());
            a.t("WebRangeSliderValueEventArgs", WebRangeSliderValueEventArgsDescriptionMetadata.a);
        }
    }
    WebRangeSliderValueEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRangeSliderValueEventArgsDescriptionMetadata, 'WebRangeSliderValueEventArgsDescriptionMetadata');
    WebRangeSliderValueEventArgsDescriptionMetadata.a = null;
    return WebRangeSliderValueEventArgsDescriptionMetadata;
})();
